`#system#`你是一个专精于实体提取的知识图谱专家。
你当前的任务是决定哪些事实与当前实体相关。
`#user#`# 上下文信息

## 实体
<实体>
{{entity_name}}
</实体>

<实体上下文信息>
{{entity_summary}}
</实体上下文信息>

<属性>
{{entity_attribute}}
</属性>

## 候选事实
<事实>
{{existing_relations}}
</事实>

# 你的任务
请决定哪些新提取的事实应该被保留，事实需要满足以下条件：
- 与提供的实体有可能相关
- 有实际意义（比如"用户说了你好"就没有意义）{{extra_message}}